# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/integration_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.integration import integration_pb2 as qwak_dot_integration_dot_integration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/integration/integration_service.proto\x12\x1bqwak.integration.management\x1a\"qwak/integration/integration.proto\"b\n\x18\x43reateIntegrationRequest\x12\x46\n\x10integration_spec\x18\x01 \x01(\x0b\x32,.qwak.integration.management.IntegrationSpec\"a\n\x19\x43reateIntegrationResponse\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x15\n\ris_successful\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"/\n\x15GetIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"W\n\x16GetIntegrationResponse\x12=\n\x0bintegration\x18\x01 \x01(\x0b\x32(.qwak.integration.management.Integration\"\x18\n\x16ListIntegrationRequest\"Z\n\x18ListIntegrationsResponse\x12>\n\x0cintegrations\x18\x01 \x03(\x0b\x32(.qwak.integration.management.Integration\"z\n\x18UpdateIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x46\n\x10integration_spec\x18\x02 \x01(\x0b\x32,.qwak.integration.management.IntegrationSpec\"\x1b\n\x19UpdateIntegrationResponse\"2\n\x18\x44\x65leteIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65leteIntegrationResponse\"m\n\x1aValidateIntegrationRequest\x12O\n\x0fvalidation_spec\x18\x01 \x01(\x0b\x32\x36.qwak.integration.management.IntegrationValidationSpec\"g\n\x1bValidateIntegrationResponse\x12H\n\x06result\x18\x01 \x01(\x0b\x32\x38.qwak.integration.management.ValidationIntegrationResult\"6\n\x1cGetIntegrationOptionsRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"a\n\x1dGetIntegrationOptionsResponse\x12@\n\x07options\x18\x01 \x01(\x0b\x32/.qwak.integration.management.IntegrationOptions2\xc4\x07\n\x1cIntegrationManagementService\x12\x82\x01\n\x11\x43reateIntegration\x12\x35.qwak.integration.management.CreateIntegrationRequest\x1a\x36.qwak.integration.management.CreateIntegrationResponse\x12y\n\x0eGetIntegration\x12\x32.qwak.integration.management.GetIntegrationRequest\x1a\x33.qwak.integration.management.GetIntegrationResponse\x12~\n\x10ListIntegrations\x12\x33.qwak.integration.management.ListIntegrationRequest\x1a\x35.qwak.integration.management.ListIntegrationsResponse\x12\x82\x01\n\x11UpdateIntegration\x12\x35.qwak.integration.management.UpdateIntegrationRequest\x1a\x36.qwak.integration.management.UpdateIntegrationResponse\x12\x82\x01\n\x11\x44\x65leteIntegration\x12\x35.qwak.integration.management.DeleteIntegrationRequest\x1a\x36.qwak.integration.management.DeleteIntegrationResponse\x12\x88\x01\n\x13ValidateIntegration\x12\x37.qwak.integration.management.ValidateIntegrationRequest\x1a\x38.qwak.integration.management.ValidateIntegrationResponse\x12\x8e\x01\n\x15GetIntegrationOptions\x12\x39.qwak.integration.management.GetIntegrationOptionsRequest\x1a:.qwak.integration.management.GetIntegrationOptionsResponseBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')



_CREATEINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateIntegrationRequest']
_CREATEINTEGRATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateIntegrationResponse']
_GETINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['GetIntegrationRequest']
_GETINTEGRATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetIntegrationResponse']
_LISTINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['ListIntegrationRequest']
_LISTINTEGRATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListIntegrationsResponse']
_UPDATEINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateIntegrationRequest']
_UPDATEINTEGRATIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateIntegrationResponse']
_DELETEINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteIntegrationRequest']
_DELETEINTEGRATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteIntegrationResponse']
_VALIDATEINTEGRATIONREQUEST = DESCRIPTOR.message_types_by_name['ValidateIntegrationRequest']
_VALIDATEINTEGRATIONRESPONSE = DESCRIPTOR.message_types_by_name['ValidateIntegrationResponse']
_GETINTEGRATIONOPTIONSREQUEST = DESCRIPTOR.message_types_by_name['GetIntegrationOptionsRequest']
_GETINTEGRATIONOPTIONSRESPONSE = DESCRIPTOR.message_types_by_name['GetIntegrationOptionsResponse']
CreateIntegrationRequest = _reflection.GeneratedProtocolMessageType('CreateIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.CreateIntegrationRequest)
  })
_sym_db.RegisterMessage(CreateIntegrationRequest)

CreateIntegrationResponse = _reflection.GeneratedProtocolMessageType('CreateIntegrationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINTEGRATIONRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.CreateIntegrationResponse)
  })
_sym_db.RegisterMessage(CreateIntegrationResponse)

GetIntegrationRequest = _reflection.GeneratedProtocolMessageType('GetIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.GetIntegrationRequest)
  })
_sym_db.RegisterMessage(GetIntegrationRequest)

GetIntegrationResponse = _reflection.GeneratedProtocolMessageType('GetIntegrationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTEGRATIONRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.GetIntegrationResponse)
  })
_sym_db.RegisterMessage(GetIntegrationResponse)

ListIntegrationRequest = _reflection.GeneratedProtocolMessageType('ListIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.ListIntegrationRequest)
  })
_sym_db.RegisterMessage(ListIntegrationRequest)

ListIntegrationsResponse = _reflection.GeneratedProtocolMessageType('ListIntegrationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINTEGRATIONSRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.ListIntegrationsResponse)
  })
_sym_db.RegisterMessage(ListIntegrationsResponse)

UpdateIntegrationRequest = _reflection.GeneratedProtocolMessageType('UpdateIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.UpdateIntegrationRequest)
  })
_sym_db.RegisterMessage(UpdateIntegrationRequest)

UpdateIntegrationResponse = _reflection.GeneratedProtocolMessageType('UpdateIntegrationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINTEGRATIONRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.UpdateIntegrationResponse)
  })
_sym_db.RegisterMessage(UpdateIntegrationResponse)

DeleteIntegrationRequest = _reflection.GeneratedProtocolMessageType('DeleteIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.DeleteIntegrationRequest)
  })
_sym_db.RegisterMessage(DeleteIntegrationRequest)

DeleteIntegrationResponse = _reflection.GeneratedProtocolMessageType('DeleteIntegrationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINTEGRATIONRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.DeleteIntegrationResponse)
  })
_sym_db.RegisterMessage(DeleteIntegrationResponse)

ValidateIntegrationRequest = _reflection.GeneratedProtocolMessageType('ValidateIntegrationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEINTEGRATIONREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.ValidateIntegrationRequest)
  })
_sym_db.RegisterMessage(ValidateIntegrationRequest)

ValidateIntegrationResponse = _reflection.GeneratedProtocolMessageType('ValidateIntegrationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEINTEGRATIONRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.ValidateIntegrationResponse)
  })
_sym_db.RegisterMessage(ValidateIntegrationResponse)

GetIntegrationOptionsRequest = _reflection.GeneratedProtocolMessageType('GetIntegrationOptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTEGRATIONOPTIONSREQUEST,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.GetIntegrationOptionsRequest)
  })
_sym_db.RegisterMessage(GetIntegrationOptionsRequest)

GetIntegrationOptionsResponse = _reflection.GeneratedProtocolMessageType('GetIntegrationOptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTEGRATIONOPTIONSRESPONSE,
  '__module__' : 'qwak.integration.integration_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.integration.management.GetIntegrationOptionsResponse)
  })
_sym_db.RegisterMessage(GetIntegrationOptionsResponse)

_INTEGRATIONMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['IntegrationManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _CREATEINTEGRATIONREQUEST._serialized_start=111
  _CREATEINTEGRATIONREQUEST._serialized_end=209
  _CREATEINTEGRATIONRESPONSE._serialized_start=211
  _CREATEINTEGRATIONRESPONSE._serialized_end=308
  _GETINTEGRATIONREQUEST._serialized_start=310
  _GETINTEGRATIONREQUEST._serialized_end=357
  _GETINTEGRATIONRESPONSE._serialized_start=359
  _GETINTEGRATIONRESPONSE._serialized_end=446
  _LISTINTEGRATIONREQUEST._serialized_start=448
  _LISTINTEGRATIONREQUEST._serialized_end=472
  _LISTINTEGRATIONSRESPONSE._serialized_start=474
  _LISTINTEGRATIONSRESPONSE._serialized_end=564
  _UPDATEINTEGRATIONREQUEST._serialized_start=566
  _UPDATEINTEGRATIONREQUEST._serialized_end=688
  _UPDATEINTEGRATIONRESPONSE._serialized_start=690
  _UPDATEINTEGRATIONRESPONSE._serialized_end=717
  _DELETEINTEGRATIONREQUEST._serialized_start=719
  _DELETEINTEGRATIONREQUEST._serialized_end=769
  _DELETEINTEGRATIONRESPONSE._serialized_start=771
  _DELETEINTEGRATIONRESPONSE._serialized_end=798
  _VALIDATEINTEGRATIONREQUEST._serialized_start=800
  _VALIDATEINTEGRATIONREQUEST._serialized_end=909
  _VALIDATEINTEGRATIONRESPONSE._serialized_start=911
  _VALIDATEINTEGRATIONRESPONSE._serialized_end=1014
  _GETINTEGRATIONOPTIONSREQUEST._serialized_start=1016
  _GETINTEGRATIONOPTIONSREQUEST._serialized_end=1070
  _GETINTEGRATIONOPTIONSRESPONSE._serialized_start=1072
  _GETINTEGRATIONOPTIONSRESPONSE._serialized_end=1169
  _INTEGRATIONMANAGEMENTSERVICE._serialized_start=1172
  _INTEGRATIONMANAGEMENTSERVICE._serialized_end=2136
# @@protoc_insertion_point(module_scope)



import json
import os
from typing import Dict, Iterable, List, Optional, Union
from urllib.parse import urljoin

import requests
from dacite import Config, from_dict
from qwak.exceptions.qwak_external_exception import QwakExternalException
from qwak.llmops.generation._steaming import BaseSSEDecoder  # noqa
from qwak.llmops.generation.chat.openai.types.chat.chat_completion import ChatCompletion
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_chunk import (
    ChatCompletionChunk,
)
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_tool_choice_option_param import (
    ChatCompletionToolChoiceOptionParam,
)
from qwak.llmops.generation.chat.openai.types.chat.chat_completion_tool_param import (
    ChatCompletionToolParam,
)
from qwak.llmops.generation.streaming import ChatCompletionStream
from qwak.utils.dict_utils import remove_none_value_keys
from requests import Response
from typing_extensions import Literal


class OpenAIChatCompletionStream(
    BaseSSEDecoder[ChatCompletionChunk], ChatCompletionStream
):
    def __init__(self, response: requests.Response):
        super().__init__(response=response, parse_to=ChatCompletionChunk)


class OpenAIClient:
    base_url: str

    def __init__(self):
        self.base_url: str = os.environ.get(
            "_QWAK_OPEN_AI_BASE_URL", "https://api.openai.com"
        )

    def invoke_chat_completion(
        self,
        api_key: str,
        model: str,
        messages: List[Dict],
        frequency_penalty: Optional[float] = None,
        logit_bias: Optional[Dict[str, int]] = None,
        logprobs: Optional[bool] = None,
        max_tokens: Optional[int] = None,
        n: Optional[int] = None,
        presence_penalty: Optional[float] = None,
        response_format: Literal["text", "json_object"] = None,
        seed: Optional[int] = None,
        stop: Union[Optional[str], List[str]] = None,
        stream: Optional[bool] = False,
        temperature: Optional[float] = None,
        top_logprobs: Optional[int] = None,
        top_p: Optional[float] = None,
        user: Optional[str] = None,
        tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
        tools: Iterable[ChatCompletionToolParam] = None,
        extra_headers: Optional[Dict[str, str]] = None,
        extra_body: Optional[Dict[str, str]] = None,
        timeout_seconds: Optional[float] = None,
    ) -> Union[ChatCompletion, ChatCompletionStream]:
        url: str = urljoin(self.base_url, "v1/chat/completions")
        headers: Dict[str, str] = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {api_key}",
        }
        body = {
            "messages": messages,
            "model": model,
            "frequency_penalty": frequency_penalty,
            "logit_bias": logit_bias,
            "logprobs": logprobs,
            "max_tokens": max_tokens,
            "n": n,
            "presence_penalty": presence_penalty,
            "response_format": {"type": response_format} if response_format else None,
            "seed": seed,
            "stop": stop,
            "temperature": temperature,
            "tool_choice": tool_choice if tools else None,
            "tools": tools if tools else None,
            "top_logprobs": top_logprobs,
            "top_p": top_p,
            "user": user,
            "stream": stream if stream else None,
        }
        body = remove_none_value_keys(body)

        if extra_headers:
            headers.update(extra_headers)

        if extra_body:
            body.update(extra_body)

        http_request_timeout_seconds: float = (
            timeout_seconds
            if timeout_seconds
            else float(os.environ.get("_QWAK_OPEN_AI_TIMEOUT_SECONDS", 60.0))
        )
        response: Response = requests.post(
            url=url,
            data=json.dumps(body),
            headers=headers,
            stream=stream,
            timeout=http_request_timeout_seconds,
        )

        try:
            response.raise_for_status()
        except requests.exceptions.HTTPError as e:
            raise QwakExternalException(message=e.response.content.decode())
        if stream:
            return OpenAIChatCompletionStream(response=response)
        else:
            return from_dict(
                data_class=ChatCompletion,
                data=response.json(),
                config=Config(check_types=False),
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.administration.v0.users.user_pb2
import qwak.self_service.account.v0.managing_account_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _JoiningInvitationStatusCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JoiningInvitationStatusCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JoiningInvitationStatusCode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOINING_INVITATION_STATUS_CODE_INVALID: _JoiningInvitationStatusCode.ValueType  # 0
    PENDING: _JoiningInvitationStatusCode.ValueType  # 1
    """Waiting for response"""
    CANCELLED: _JoiningInvitationStatusCode.ValueType  # 2
    """Canceled by account user"""
    DECLINED: _JoiningInvitationStatusCode.ValueType  # 3
    """Declined by invitee"""
    ACCEPTED: _JoiningInvitationStatusCode.ValueType  # 4
    """Accepted by invitee"""

class JoiningInvitationStatusCode(_JoiningInvitationStatusCode, metaclass=_JoiningInvitationStatusCodeEnumTypeWrapper): ...

JOINING_INVITATION_STATUS_CODE_INVALID: JoiningInvitationStatusCode.ValueType  # 0
PENDING: JoiningInvitationStatusCode.ValueType  # 1
"""Waiting for response"""
CANCELLED: JoiningInvitationStatusCode.ValueType  # 2
"""Canceled by account user"""
DECLINED: JoiningInvitationStatusCode.ValueType  # 3
"""Declined by invitee"""
ACCEPTED: JoiningInvitationStatusCode.ValueType  # 4
"""Accepted by invitee"""
global___JoiningInvitationStatusCode = JoiningInvitationStatusCode

class InviteOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def invitation_spec(self) -> global___JoiningInvitationSpec:
        """Spec of the invitation"""
    def __init__(
        self,
        *,
        invitation_spec: global___JoiningInvitationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["invitation_spec", b"invitation_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_spec", b"invitation_spec"]) -> None: ...

global___InviteOptions = InviteOptions

class JoiningInvitationDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NUM_OF_ACCOUNT_MEMBERS_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___JoiningInvitationMetadata:
        """The metadata of the invitation"""
    @property
    def spec(self) -> global___JoiningInvitationSpec:
        """The spec of the invitation"""
    @property
    def status(self) -> global___JoiningInvitationStatus:
        """Status information for invitation"""
    num_of_account_members: builtins.int
    """The number of account members"""
    account_name: builtins.str
    """The account name"""
    def __init__(
        self,
        *,
        metadata: global___JoiningInvitationMetadata | None = ...,
        spec: global___JoiningInvitationSpec | None = ...,
        status: global___JoiningInvitationStatus | None = ...,
        num_of_account_members: builtins.int = ...,
        account_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "metadata", b"metadata", "num_of_account_members", b"num_of_account_members", "spec", b"spec", "status", b"status"]) -> None: ...

global___JoiningInvitationDescription = JoiningInvitationDescription

class JoiningInvitationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    INVITED_BY_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Created at"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expired at"""
    invited_by: builtins.str
    """The user id of the inviting user"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        invited_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "expired_at", b"expired_at", "invitation_id", b"invitation_id", "invited_by", b"invited_by"]) -> None: ...

global___JoiningInvitationMetadata = JoiningInvitationMetadata

class JoiningInvitationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentIdToDescriptionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentDescription: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentDescription | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    INVITEE_EMAIL_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_NAMES_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_TO_DESCRIPTION_FIELD_NUMBER: builtins.int
    invitee_email: builtins.str
    """The email of the invitee"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Bind user to environment ids"""
    @property
    def environment_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Bind user to environment names"""
    @property
    def environment_id_to_description(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentDescription]:
        """Bind user to environment ids and descriptions"""
    def __init__(
        self,
        *,
        invitee_email: builtins.str = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
        environment_names: collections.abc.Iterable[builtins.str] | None = ...,
        environment_id_to_description: collections.abc.Mapping[builtins.str, global___EnvironmentDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "environment_id_to_description", b"environment_id_to_description", "environment_ids", b"environment_ids", "environment_names", b"environment_names", "invitee_email", b"invitee_email"]) -> None: ...

global___JoiningInvitationSpec = JoiningInvitationSpec

class JoiningInvitationStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    LAST_CHANGED_AT_FIELD_NUMBER: builtins.int
    code: global___JoiningInvitationStatusCode.ValueType
    """status code"""
    @property
    def last_changed_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the status has been changed"""
    def __init__(
        self,
        *,
        code: global___JoiningInvitationStatusCode.ValueType = ...,
        last_changed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_changed_at", b"last_changed_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "last_changed_at", b"last_changed_at"]) -> None: ...

global___JoiningInvitationStatus = JoiningInvitationStatus

class UserAccountDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentIdToDescriptionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentDescription: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentDescription | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    IS_DEFAULT_ACCOUNT_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_NAMES_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_TO_DESCRIPTION_FIELD_NUMBER: builtins.int
    account_name: builtins.str
    """The account name"""
    is_default_account: builtins.bool
    """Indicate whether is default account"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    @property
    def environment_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Bind user environment names"""
    @property
    def environment_id_to_description(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentDescription]:
        """User environments ids to their description"""
    def __init__(
        self,
        *,
        account_name: builtins.str = ...,
        is_default_account: builtins.bool = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_names: collections.abc.Iterable[builtins.str] | None = ...,
        environment_id_to_description: collections.abc.Mapping[builtins.str, global___EnvironmentDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "account_role", b"account_role", "environment_id_to_description", b"environment_id_to_description", "environment_names", b"environment_names", "is_default_account", b"is_default_account"]) -> None: ...

global___UserAccountDescription = UserAccountDescription

class EnvironmentDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    environment_name: builtins.str
    """The environment name"""
    cloud_provider: qwak.self_service.account.v0.managing_account_pb2.CloudProvider.ValueType
    """The cloud provider"""
    def __init__(
        self,
        *,
        environment_name: builtins.str = ...,
        cloud_provider: qwak.self_service.account.v0.managing_account_pb2.CloudProvider.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_provider", b"cloud_provider", "environment_name", b"environment_name"]) -> None: ...

global___EnvironmentDescription = EnvironmentDescription



import re
from dataclasses import dataclass
from enum import Enum
from typing import List, Type

from _qwak_proto.qwak.feature_store.features.aggregation_pb2 import (
    TimeUnit as ProtoTimeUnit,
)
from qwak.exceptions import QwakException


class _WindowTimeUnitMapping(Enum):
    WEEKS = (ProtoTimeUnit.TIME_UNIT_WEEKS, 7 * 24 * 60 * 60, "w")
    DAYS = (ProtoTimeUnit.TIME_UNIT_DAYS, 24 * 60 * 60, "d")
    HOURS = (ProtoTimeUnit.TIME_UNIT_HOURS, 60 * 60, "h")
    MINUTES = (ProtoTimeUnit.TIME_UNIT_MINUTES, 60, "m")
    SECONDS = (ProtoTimeUnit.TIME_UNIT_SECONDS, 1, "s")

    # Aliases
    WEEK = WEEKS
    DAY = DAYS
    HOUR = HOURS
    MINUTE = MINUTES
    SECOND = SECONDS


@dataclass
class Window:
    length: int
    time_unit_proto: ProtoTimeUnit
    seconds_in_time_unit: int
    suffix: str

    def get_feature_suffix(self) -> str:
        return f"{self.length}{self.suffix}"

    @classmethod
    def _from_string(cls, *windows: str) -> List[Type["Window"]]:
        time_window_parser = re.compile(
            rf'(?P<length>\d+)\s+(?P<timeunit>{"|".join([name.lower() for name, member in _WindowTimeUnitMapping.__members__.items()])})$'
        )

        parsed_windows: List[Window] = list()
        for window in windows:
            match = time_window_parser.match(window.lower())
            if not match:
                raise QwakException(
                    f"""
                        Could not parse given time window: {window}.
                        Valid time windows should be of the form "X weeks/days/hours/minutes/seconds", where X is a number.
                        For example - "1 hour", "2 days", "1 week", etc.
                    """
                )

            m_dict = match.groupdict()
            proto, minutes_in_unit, suffix = getattr(
                _WindowTimeUnitMapping, m_dict["timeunit"].upper()
            ).value

            additional_window = cls(
                length=int(m_dict["length"]),
                seconds_in_time_unit=minutes_in_unit,
                time_unit_proto=proto,
                suffix=suffix,
            )

            if additional_window not in parsed_windows:
                parsed_windows.append(additional_window)

        return parsed_windows



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.execution.v1.jobs import job_pb2 as qwak_dot_execution_dot_v1_dot_jobs_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/execution/v1/jobs/job_service.proto\x12$qwak.feature.store.execution.v1.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/execution/v1/jobs/job.proto\"\\\n\x15\x41pplyJobRecordRequest\x12\x43\n\njob_record\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\"\x18\n\x16\x41pplyJobRecordResponse\".\n\x15InitPaginationRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"E\n\x16InitPaginationResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x15\n\rmax_record_id\x18\x02 \x01(\x03\"g\n\x0fListJobsRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x15\n\rmax_record_id\x18\x04 \x01(\x03\"X\n\x10ListJobsResponse\x12\x44\n\x0bjob_records\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\":\n\"InitPaginationByExecutionIdRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"R\n#InitPaginationByExecutionIdResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x15\n\rmax_record_id\x18\x02 \x01(\x03\"s\n\x1cListJobsByExecutionIdRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x15\n\rmax_record_id\x18\x04 \x01(\x03\"e\n\x1dListJobsByExecutionIdResponse\x12\x44\n\x0bjob_records\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\"4\n\x1b\x44\x65leteFeaturesetJobsRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"@\n\x1c\x44\x65leteFeaturesetJobsResponse\x12 \n\x18\x64\x65leted_job_record_count\x18\x01 \x01(\x03\"D\n+GetLatestSuccessfulJobByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"\x88\x01\n,GetLatestSuccessfulJobByFeaturesetIdResponse\x12\x45\n\njob_record\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecordH\x00\x42\x11\n\x0fjob_record_resp\"-\n+GetAllFeaturesetLatestSuccessfulJobsRequest\"t\n,GetAllFeaturesetLatestSuccessfulJobsResponse\x12\x44\n\x0bjob_records\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\"\xa3\x01\n$GetAllFeaturesetJobsSummariesRequest\x12\x34\n\x10lower_time_bound\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x10upper_time_bound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\r\n\x0bupper_bound\"|\n%GetAllFeaturesetJobsSummariesResponse\x12S\n\x0ejobs_summaries\x18\x01 \x03(\x0b\x32;.qwak.feature.store.execution.v1.jobs.FeaturesetJobsSummary\"K\n\x15\x46\x65\x61turesetJobsSummary\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x1b\n\x13total_affected_rows\x18\x02 \x01(\x03\":\n\"GetJobsSummaryByExecutionIdRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x80\x02\n#GetJobsSummaryByExecutionIdResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x11\n\tjob_count\x18\x02 \x01(\x03\x12\x1b\n\x13total_affected_rows\x18\x03 \x01(\x03\x12I\n\x10\x66irst_job_record\x18\x04 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\x12H\n\x0flast_job_record\x18\x05 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecord\"=\n$GetJobSummariesByExecutionIdsRequest\x12\x15\n\rexecution_ids\x18\x01 \x03(\t\"\x80\x01\n%GetJobSummariesByExecutionIdsResponse\x12W\n\x13\x65xecution_summaries\x18\x01 \x03(\x0b\x32:.qwak.feature.store.execution.v1.jobs.ExecutionJobsSummary\"\xa4\x02\n\x14\x45xecutionJobsSummary\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x11\n\tjob_count\x18\x02 \x01(\x03\x12\x1b\n\x13total_affected_rows\x18\x03 \x01(\x03\x12K\n\x10\x66irst_job_record\x18\x04 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecordH\x00\x12J\n\x0flast_job_record\x18\x05 \x01(\x0b\x32/.qwak.feature.store.execution.v1.jobs.JobRecordH\x01\x42\x16\n\x14\x66irst_job_record_optB\x15\n\x13last_job_record_opt2\xe6\x0e\n\nJobService\x12\x8b\x01\n\x0e\x41pplyJobRecord\x12;.qwak.feature.store.execution.v1.jobs.ApplyJobRecordRequest\x1a<.qwak.feature.store.execution.v1.jobs.ApplyJobRecordResponse\x12\x8b\x01\n\x0eInitPagination\x12;.qwak.feature.store.execution.v1.jobs.InitPaginationRequest\x1a<.qwak.feature.store.execution.v1.jobs.InitPaginationResponse\x12y\n\x08ListJobs\x12\x35.qwak.feature.store.execution.v1.jobs.ListJobsRequest\x1a\x36.qwak.feature.store.execution.v1.jobs.ListJobsResponse\x12\xb2\x01\n\x1bInitPaginationByExecutionId\x12H.qwak.feature.store.execution.v1.jobs.InitPaginationByExecutionIdRequest\x1aI.qwak.feature.store.execution.v1.jobs.InitPaginationByExecutionIdResponse\x12\xa0\x01\n\x15ListJobsByExecutionId\x12\x42.qwak.feature.store.execution.v1.jobs.ListJobsByExecutionIdRequest\x1a\x43.qwak.feature.store.execution.v1.jobs.ListJobsByExecutionIdResponse\x12\x9d\x01\n\x14\x44\x65leteFeaturesetJobs\x12\x41.qwak.feature.store.execution.v1.jobs.DeleteFeaturesetJobsRequest\x1a\x42.qwak.feature.store.execution.v1.jobs.DeleteFeaturesetJobsResponse\x12\xcd\x01\n$GetLatestSuccessfulJobByFeaturesetId\x12Q.qwak.feature.store.execution.v1.jobs.GetLatestSuccessfulJobByFeaturesetIdRequest\x1aR.qwak.feature.store.execution.v1.jobs.GetLatestSuccessfulJobByFeaturesetIdResponse\x12\xcd\x01\n$GetAllFeaturesetLatestSuccessfulJobs\x12Q.qwak.feature.store.execution.v1.jobs.GetAllFeaturesetLatestSuccessfulJobsRequest\x1aR.qwak.feature.store.execution.v1.jobs.GetAllFeaturesetLatestSuccessfulJobsResponse\x12\xb8\x01\n\x1dGetAllFeaturesetJobsSummaries\x12J.qwak.feature.store.execution.v1.jobs.GetAllFeaturesetJobsSummariesRequest\x1aK.qwak.feature.store.execution.v1.jobs.GetAllFeaturesetJobsSummariesResponse\x12\xb2\x01\n\x1bGetJobsSummaryByExecutionId\x12H.qwak.feature.store.execution.v1.jobs.GetJobsSummaryByExecutionIdRequest\x1aI.qwak.feature.store.execution.v1.jobs.GetJobsSummaryByExecutionIdResponse\x12\xb8\x01\n\x1dGetJobSummariesByExecutionIds\x12J.qwak.feature.store.execution.v1.jobs.GetJobSummariesByExecutionIdsRequest\x1aK.qwak.feature.store.execution.v1.jobs.GetJobSummariesByExecutionIdsResponseBG\n*com.qwak.ai.features.execution.api.v1.jobsP\x01Z\x17qwak/fsexecution;fsjobsb\x06proto3')



_APPLYJOBRECORDREQUEST = DESCRIPTOR.message_types_by_name['ApplyJobRecordRequest']
_APPLYJOBRECORDRESPONSE = DESCRIPTOR.message_types_by_name['ApplyJobRecordResponse']
_INITPAGINATIONREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationRequest']
_INITPAGINATIONRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationResponse']
_LISTJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListJobsRequest']
_LISTJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListJobsResponse']
_INITPAGINATIONBYEXECUTIONIDREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationByExecutionIdRequest']
_INITPAGINATIONBYEXECUTIONIDRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationByExecutionIdResponse']
_LISTJOBSBYEXECUTIONIDREQUEST = DESCRIPTOR.message_types_by_name['ListJobsByExecutionIdRequest']
_LISTJOBSBYEXECUTIONIDRESPONSE = DESCRIPTOR.message_types_by_name['ListJobsByExecutionIdResponse']
_DELETEFEATURESETJOBSREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturesetJobsRequest']
_DELETEFEATURESETJOBSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturesetJobsResponse']
_GETLATESTSUCCESSFULJOBBYFEATURESETIDREQUEST = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobByFeaturesetIdRequest']
_GETLATESTSUCCESSFULJOBBYFEATURESETIDRESPONSE = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobByFeaturesetIdResponse']
_GETALLFEATURESETLATESTSUCCESSFULJOBSREQUEST = DESCRIPTOR.message_types_by_name['GetAllFeaturesetLatestSuccessfulJobsRequest']
_GETALLFEATURESETLATESTSUCCESSFULJOBSRESPONSE = DESCRIPTOR.message_types_by_name['GetAllFeaturesetLatestSuccessfulJobsResponse']
_GETALLFEATURESETJOBSSUMMARIESREQUEST = DESCRIPTOR.message_types_by_name['GetAllFeaturesetJobsSummariesRequest']
_GETALLFEATURESETJOBSSUMMARIESRESPONSE = DESCRIPTOR.message_types_by_name['GetAllFeaturesetJobsSummariesResponse']
_FEATURESETJOBSSUMMARY = DESCRIPTOR.message_types_by_name['FeaturesetJobsSummary']
_GETJOBSSUMMARYBYEXECUTIONIDREQUEST = DESCRIPTOR.message_types_by_name['GetJobsSummaryByExecutionIdRequest']
_GETJOBSSUMMARYBYEXECUTIONIDRESPONSE = DESCRIPTOR.message_types_by_name['GetJobsSummaryByExecutionIdResponse']
_GETJOBSUMMARIESBYEXECUTIONIDSREQUEST = DESCRIPTOR.message_types_by_name['GetJobSummariesByExecutionIdsRequest']
_GETJOBSUMMARIESBYEXECUTIONIDSRESPONSE = DESCRIPTOR.message_types_by_name['GetJobSummariesByExecutionIdsResponse']
_EXECUTIONJOBSSUMMARY = DESCRIPTOR.message_types_by_name['ExecutionJobsSummary']
ApplyJobRecordRequest = _reflection.GeneratedProtocolMessageType('ApplyJobRecordRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBRECORDREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ApplyJobRecordRequest)
  })
_sym_db.RegisterMessage(ApplyJobRecordRequest)

ApplyJobRecordResponse = _reflection.GeneratedProtocolMessageType('ApplyJobRecordResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBRECORDRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ApplyJobRecordResponse)
  })
_sym_db.RegisterMessage(ApplyJobRecordResponse)

InitPaginationRequest = _reflection.GeneratedProtocolMessageType('InitPaginationRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.InitPaginationRequest)
  })
_sym_db.RegisterMessage(InitPaginationRequest)

InitPaginationResponse = _reflection.GeneratedProtocolMessageType('InitPaginationResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.InitPaginationResponse)
  })
_sym_db.RegisterMessage(InitPaginationResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

InitPaginationByExecutionIdRequest = _reflection.GeneratedProtocolMessageType('InitPaginationByExecutionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYEXECUTIONIDREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.InitPaginationByExecutionIdRequest)
  })
_sym_db.RegisterMessage(InitPaginationByExecutionIdRequest)

InitPaginationByExecutionIdResponse = _reflection.GeneratedProtocolMessageType('InitPaginationByExecutionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYEXECUTIONIDRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.InitPaginationByExecutionIdResponse)
  })
_sym_db.RegisterMessage(InitPaginationByExecutionIdResponse)

ListJobsByExecutionIdRequest = _reflection.GeneratedProtocolMessageType('ListJobsByExecutionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSBYEXECUTIONIDREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ListJobsByExecutionIdRequest)
  })
_sym_db.RegisterMessage(ListJobsByExecutionIdRequest)

ListJobsByExecutionIdResponse = _reflection.GeneratedProtocolMessageType('ListJobsByExecutionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSBYEXECUTIONIDRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ListJobsByExecutionIdResponse)
  })
_sym_db.RegisterMessage(ListJobsByExecutionIdResponse)

DeleteFeaturesetJobsRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.DeleteFeaturesetJobsRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetJobsRequest)

DeleteFeaturesetJobsResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.DeleteFeaturesetJobsResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturesetJobsResponse)

GetLatestSuccessfulJobByFeaturesetIdRequest = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobByFeaturesetIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBBYFEATURESETIDREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetLatestSuccessfulJobByFeaturesetIdRequest)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobByFeaturesetIdRequest)

GetLatestSuccessfulJobByFeaturesetIdResponse = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobByFeaturesetIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBBYFEATURESETIDRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetLatestSuccessfulJobByFeaturesetIdResponse)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobByFeaturesetIdResponse)

GetAllFeaturesetLatestSuccessfulJobsRequest = _reflection.GeneratedProtocolMessageType('GetAllFeaturesetLatestSuccessfulJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESETLATESTSUCCESSFULJOBSREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetAllFeaturesetLatestSuccessfulJobsRequest)
  })
_sym_db.RegisterMessage(GetAllFeaturesetLatestSuccessfulJobsRequest)

GetAllFeaturesetLatestSuccessfulJobsResponse = _reflection.GeneratedProtocolMessageType('GetAllFeaturesetLatestSuccessfulJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESETLATESTSUCCESSFULJOBSRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetAllFeaturesetLatestSuccessfulJobsResponse)
  })
_sym_db.RegisterMessage(GetAllFeaturesetLatestSuccessfulJobsResponse)

GetAllFeaturesetJobsSummariesRequest = _reflection.GeneratedProtocolMessageType('GetAllFeaturesetJobsSummariesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESETJOBSSUMMARIESREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetAllFeaturesetJobsSummariesRequest)
  })
_sym_db.RegisterMessage(GetAllFeaturesetJobsSummariesRequest)

GetAllFeaturesetJobsSummariesResponse = _reflection.GeneratedProtocolMessageType('GetAllFeaturesetJobsSummariesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESETJOBSSUMMARIESRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetAllFeaturesetJobsSummariesResponse)
  })
_sym_db.RegisterMessage(GetAllFeaturesetJobsSummariesResponse)

FeaturesetJobsSummary = _reflection.GeneratedProtocolMessageType('FeaturesetJobsSummary', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETJOBSSUMMARY,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.FeaturesetJobsSummary)
  })
_sym_db.RegisterMessage(FeaturesetJobsSummary)

GetJobsSummaryByExecutionIdRequest = _reflection.GeneratedProtocolMessageType('GetJobsSummaryByExecutionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSSUMMARYBYEXECUTIONIDREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetJobsSummaryByExecutionIdRequest)
  })
_sym_db.RegisterMessage(GetJobsSummaryByExecutionIdRequest)

GetJobsSummaryByExecutionIdResponse = _reflection.GeneratedProtocolMessageType('GetJobsSummaryByExecutionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSSUMMARYBYEXECUTIONIDRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetJobsSummaryByExecutionIdResponse)
  })
_sym_db.RegisterMessage(GetJobsSummaryByExecutionIdResponse)

GetJobSummariesByExecutionIdsRequest = _reflection.GeneratedProtocolMessageType('GetJobSummariesByExecutionIdsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSUMMARIESBYEXECUTIONIDSREQUEST,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetJobSummariesByExecutionIdsRequest)
  })
_sym_db.RegisterMessage(GetJobSummariesByExecutionIdsRequest)

GetJobSummariesByExecutionIdsResponse = _reflection.GeneratedProtocolMessageType('GetJobSummariesByExecutionIdsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSUMMARIESBYEXECUTIONIDSRESPONSE,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.GetJobSummariesByExecutionIdsResponse)
  })
_sym_db.RegisterMessage(GetJobSummariesByExecutionIdsResponse)

ExecutionJobsSummary = _reflection.GeneratedProtocolMessageType('ExecutionJobsSummary', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONJOBSSUMMARY,
  '__module__' : 'qwak.execution.v1.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.ExecutionJobsSummary)
  })
_sym_db.RegisterMessage(ExecutionJobsSummary)

_JOBSERVICE = DESCRIPTOR.services_by_name['JobService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.features.execution.api.v1.jobsP\001Z\027qwak/fsexecution;fsjobs'
  _APPLYJOBRECORDREQUEST._serialized_start=149
  _APPLYJOBRECORDREQUEST._serialized_end=241
  _APPLYJOBRECORDRESPONSE._serialized_start=243
  _APPLYJOBRECORDRESPONSE._serialized_end=267
  _INITPAGINATIONREQUEST._serialized_start=269
  _INITPAGINATIONREQUEST._serialized_end=315
  _INITPAGINATIONRESPONSE._serialized_start=317
  _INITPAGINATIONRESPONSE._serialized_end=386
  _LISTJOBSREQUEST._serialized_start=388
  _LISTJOBSREQUEST._serialized_end=491
  _LISTJOBSRESPONSE._serialized_start=493
  _LISTJOBSRESPONSE._serialized_end=581
  _INITPAGINATIONBYEXECUTIONIDREQUEST._serialized_start=583
  _INITPAGINATIONBYEXECUTIONIDREQUEST._serialized_end=641
  _INITPAGINATIONBYEXECUTIONIDRESPONSE._serialized_start=643
  _INITPAGINATIONBYEXECUTIONIDRESPONSE._serialized_end=725
  _LISTJOBSBYEXECUTIONIDREQUEST._serialized_start=727
  _LISTJOBSBYEXECUTIONIDREQUEST._serialized_end=842
  _LISTJOBSBYEXECUTIONIDRESPONSE._serialized_start=844
  _LISTJOBSBYEXECUTIONIDRESPONSE._serialized_end=945
  _DELETEFEATURESETJOBSREQUEST._serialized_start=947
  _DELETEFEATURESETJOBSREQUEST._serialized_end=999
  _DELETEFEATURESETJOBSRESPONSE._serialized_start=1001
  _DELETEFEATURESETJOBSRESPONSE._serialized_end=1065
  _GETLATESTSUCCESSFULJOBBYFEATURESETIDREQUEST._serialized_start=1067
  _GETLATESTSUCCESSFULJOBBYFEATURESETIDREQUEST._serialized_end=1135
  _GETLATESTSUCCESSFULJOBBYFEATURESETIDRESPONSE._serialized_start=1138
  _GETLATESTSUCCESSFULJOBBYFEATURESETIDRESPONSE._serialized_end=1274
  _GETALLFEATURESETLATESTSUCCESSFULJOBSREQUEST._serialized_start=1276
  _GETALLFEATURESETLATESTSUCCESSFULJOBSREQUEST._serialized_end=1321
  _GETALLFEATURESETLATESTSUCCESSFULJOBSRESPONSE._serialized_start=1323
  _GETALLFEATURESETLATESTSUCCESSFULJOBSRESPONSE._serialized_end=1439
  _GETALLFEATURESETJOBSSUMMARIESREQUEST._serialized_start=1442
  _GETALLFEATURESETJOBSSUMMARIESREQUEST._serialized_end=1605
  _GETALLFEATURESETJOBSSUMMARIESRESPONSE._serialized_start=1607
  _GETALLFEATURESETJOBSSUMMARIESRESPONSE._serialized_end=1731
  _FEATURESETJOBSSUMMARY._serialized_start=1733
  _FEATURESETJOBSSUMMARY._serialized_end=1808
  _GETJOBSSUMMARYBYEXECUTIONIDREQUEST._serialized_start=1810
  _GETJOBSSUMMARYBYEXECUTIONIDREQUEST._serialized_end=1868
  _GETJOBSSUMMARYBYEXECUTIONIDRESPONSE._serialized_start=1871
  _GETJOBSSUMMARYBYEXECUTIONIDRESPONSE._serialized_end=2127
  _GETJOBSUMMARIESBYEXECUTIONIDSREQUEST._serialized_start=2129
  _GETJOBSUMMARIESBYEXECUTIONIDSREQUEST._serialized_end=2190
  _GETJOBSUMMARIESBYEXECUTIONIDSRESPONSE._serialized_start=2193
  _GETJOBSUMMARIESBYEXECUTIONIDSRESPONSE._serialized_end=2321
  _EXECUTIONJOBSSUMMARY._serialized_start=2324
  _EXECUTIONJOBSSUMMARY._serialized_end=2616
  _JOBSERVICE._serialized_start=2619
  _JOBSERVICE._serialized_end=4513
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.fitness_service import status_pb2 as qwak_dot_fitness__service_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/builds/builds.proto\x12\x16qwak.builds.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/deployment/deployment.proto\x1a\x17qwak/builds/build.proto\x1a!qwak/fitness_service/status.proto\"\xf4\x05\n\x05\x42uild\x12\x35\n\nbuild_spec\x18\x01 \x01(\x0b\x32!.qwak.builds.management.BuildSpec\x12\x39\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32#.qwak.builds.management.BuildStatus\x12\x39\n\x0cmodel_schema\x18\x03 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x07 \x01(\t\x12V\n\x17\x64\x65ployment_build_status\x18\x08 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatusB\x02\x18\x01\x12V\n\x14hosting_service_type\x18\t \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceType\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16\x61vailable_environments\x18\x0b \x03(\t\x12\x1d\n\x15\x64\x65ployed_environments\x18\x0c \x03(\t\x12\x32\n\tpodStatus\x18\r \x01(\x0b\x32\x1f.qwak.fitness.service.PodStatus\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12\x41\n\x0f\x62uild_initiator\x18\x0f \x01(\x0b\x32(.qwak.builds.orchestrator.BuildInitiator\"\x86\x03\n\tBuildSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x04 \x01(\t\x12\x11\n\tbranch_id\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x06 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\x12G\n\x13\x62uild_configuration\x18\x07 \x01(\x0b\x32*.qwak.builds.management.BuildConfiguration\x12\x17\n\x0f\x62uild_code_path\x18\t \x01(\t\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\"\xee\x01\n\x0bModelSchema\x12\x30\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x31\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1f.qwak.builds.management.Feature\x12\x37\n\x0bpredictions\x18\x03 \x03(\x0b\x32\".qwak.builds.management.Prediction\x12\x41\n\x10inference_output\x18\x04 \x03(\x0b\x32\'.qwak.builds.management.InferenceOutput\"G\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xd0\x04\n\x07\x46\x65\x61ture\x12=\n\rbatch_feature\x18\x01 \x01(\x0b\x32$.qwak.builds.management.BatchFeatureH\x00\x12\x43\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12\x45\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\'.qwak.builds.management.OnTheFlyFeatureH\x00\x12\x45\n\x11streaming_feature\x18\x04 \x01(\x0b\x32(.qwak.builds.management.StreamingFeatureH\x00\x12=\n\rrequest_input\x18\x05 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x12\\\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32\x33.qwak.builds.management.StreamingAggregationFeatureH\x00\x12\x42\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32&.qwak.builds.management.BatchFeatureV1H\x00\x12J\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32*.qwak.builds.management.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x8f\x01\n\x0fOnTheFlyFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x0fsource_features\x18\x03 \x03(\x0b\x32%.qwak.builds.management.SourceFeature\"N\n\x0e\x42\x61tchFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x12StreamingFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x0c\x42\x61tchFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x10StreamingFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"[\n\x1bStreamingAggregationFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"M\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\x9b\x01\n\rSourceFeature\x12\x43\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12=\n\rrequest_input\x18\x02 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x42\x06\n\x04type\"K\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"P\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xa6\x01\n\tValueType\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.qwak.builds.management.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"\xae\x01\n\x14RegisterBuildRequest\x12\x35\n\nbuild_spec\x18\x01 \x01(\x0b\x32!.qwak.builds.management.BuildSpec\x12=\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32#.qwak.builds.management.ModelSchemaB\x02\x18\x01\x12 \n\x14qwak_calling_user_id\x18\x03 \x01(\tB\x02\x18\x01\"i\n\x1aRegisterModelSchemaRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x39\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\"\x91\x01\n\'RegisterExperimentTrackingValuesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x02 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\"*\n(RegisterExperimentTrackingValuesResponse\"z\n\x18\x45xperimentTrackingValues\x12/\n\x07metrics\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Metric\x12-\n\x06params\x18\x02 \x03(\x0b\x32\x1d.qwak.builds.management.Param\"\xd1\x02\n\x12\x42uildConfiguration\x12\x46\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32,.qwak.builds.management.BuildPropertiesProto\x12;\n\tbuild_env\x18\x02 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12;\n\tpre_build\x18\x03 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12<\n\npost_build\x18\x04 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12*\n\x04step\x18\x05 \x01(\x0b\x32\x1c.qwak.builds.management.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xc4\x01\n\x14\x42uildPropertiesProto\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x38\n\tmodel_uri\x18\x02 \x01(\x0b\x32%.qwak.builds.management.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xe8\x01\n\x10\x42uildEnvironment\x12\x33\n\x06\x64ocker\x18\x01 \x01(\x0b\x32#.qwak.builds.management.DockerBuild\x12\x31\n\x05local\x18\x02 \x01(\x0b\x32\".qwak.builds.management.LocalBuild\x12\x37\n\npython_env\x18\x03 \x01(\x0b\x32#.qwak.builds.management.PythonBuild\x12\x33\n\x06remote\x18\x04 \x01(\x0b\x32#.qwak.builds.management.RemoteBuild\"\x8a\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x46\n\nbuild_args\x18\x02 \x03(\x0b\x32\x32.qwak.builds.management.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x9b\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12\x43\n\nvirtualenv\x18\x02 \x01(\x0b\x32/.qwak.builds.management.VirtualEnvironmentBuild\x12\x31\n\x05\x63onda\x18\x03 \x01(\x0b\x32\".qwak.builds.management.CondaBuild\x12\x33\n\x06poetry\x18\x04 \x01(\x0b\x32#.qwak.builds.management.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"a\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12?\n\tresources\x18\x02 \x01(\x0b\x32,.qwak.builds.management.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"$\n\x06Metric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"#\n\x05Param\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1d\n\x1bRegisterModelSchemaResponse\"d\n\x15RegisterBuildResponse\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x39\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32#.qwak.builds.management.BuildStatus\"\xa9\x01\n\x18UpdateBuildStatusRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x39\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32#.qwak.builds.management.BuildStatus\x12 \n\x14qwak_calling_user_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x1e\n\x16\x61vailable_environments\x18\x04 \x03(\t\"\x1b\n\x19UpdateBuildStatusResponse\"A\n\x18UpdateBuildBranchRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\"\x1b\n\x19UpdateBuildBranchResponse\"#\n\x0fGetBuildRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"@\n\x10GetBuildResponse\x12,\n\x05\x62uild\x18\x01 \x01(\x0b\x32\x1d.qwak.builds.management.Build\"Q\n\x11ListBuildsRequest\x12\x15\n\tbranch_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x12\n\nmodel_uuid\x18\x02 \x01(\t\x12\x11\n\tbuild_ids\x18\x03 \x03(\t\"C\n\x12ListBuildsResponse\x12-\n\x06\x62uilds\x18\x01 \x03(\x0b\x32\x1d.qwak.builds.management.Build*\xe8\x01\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\t2\xed\x05\n\x17\x42uildsManagementService\x12l\n\rRegisterBuild\x12,.qwak.builds.management.RegisterBuildRequest\x1a-.qwak.builds.management.RegisterBuildResponse\x12x\n\x11UpdateBuildStatus\x12\x30.qwak.builds.management.UpdateBuildStatusRequest\x1a\x31.qwak.builds.management.UpdateBuildStatusResponse\x12~\n\x13RegisterModelSchema\x12\x32.qwak.builds.management.RegisterModelSchemaRequest\x1a\x33.qwak.builds.management.RegisterModelSchemaResponse\x12\xa5\x01\n RegisterExperimentTrackingValues\x12?.qwak.builds.management.RegisterExperimentTrackingValuesRequest\x1a@.qwak.builds.management.RegisterExperimentTrackingValuesResponse\x12]\n\x08GetBuild\x12\'.qwak.builds.management.GetBuildRequest\x1a(.qwak.builds.management.GetBuildResponse\x12\x63\n\nListBuilds\x12).qwak.builds.management.ListBuildsRequest\x1a*.qwak.builds.management.ListBuildsResponseB%\n!com.qwak.ai.management.builds.apiP\x01\x62\x06proto3')

_BUILDSTATUS = DESCRIPTOR.enum_types_by_name['BuildStatus']
BuildStatus = enum_type_wrapper.EnumTypeWrapper(_BUILDSTATUS)
INVALID = 0
IN_PROGRESS = 1
SUCCESSFUL = 2
FAILED = 3
REMOTE_BUILD_INITIALIZING = 4
REMOTE_BUILD_CANCELLED = 5
REMOTE_BUILD_TIMED_OUT = 6
REMOTE_BUILD_UNKNOWN = 7
SYNCING_ENVIRONMENTS = 8
FINISHED_SYNCING = 9


_BUILD = DESCRIPTOR.message_types_by_name['Build']
_BUILDSPEC = DESCRIPTOR.message_types_by_name['BuildSpec']
_MODELSCHEMA = DESCRIPTOR.message_types_by_name['ModelSchema']
_ENTITY = DESCRIPTOR.message_types_by_name['Entity']
_FEATURE = DESCRIPTOR.message_types_by_name['Feature']
_ONTHEFLYFEATURE = DESCRIPTOR.message_types_by_name['OnTheFlyFeature']
_BATCHFEATUREV1 = DESCRIPTOR.message_types_by_name['BatchFeatureV1']
_STREAMINGFEATUREV1 = DESCRIPTOR.message_types_by_name['StreamingFeatureV1']
_BATCHFEATURE = DESCRIPTOR.message_types_by_name['BatchFeature']
_STREAMINGFEATURE = DESCRIPTOR.message_types_by_name['StreamingFeature']
_STREAMINGAGGREGATIONFEATURE = DESCRIPTOR.message_types_by_name['StreamingAggregationFeature']
_EXPLICITFEATURE = DESCRIPTOR.message_types_by_name['ExplicitFeature']
_REQUESTINPUT = DESCRIPTOR.message_types_by_name['RequestInput']
_SOURCEFEATURE = DESCRIPTOR.message_types_by_name['SourceFeature']
_PREDICTION = DESCRIPTOR.message_types_by_name['Prediction']
_INFERENCEOUTPUT = DESCRIPTOR.message_types_by_name['InferenceOutput']
_VALUETYPE = DESCRIPTOR.message_types_by_name['ValueType']
_PARAMETERCATEGORY = DESCRIPTOR.message_types_by_name['ParameterCategory']
_REGISTERBUILDREQUEST = DESCRIPTOR.message_types_by_name['RegisterBuildRequest']
_REGISTERMODELSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['RegisterModelSchemaRequest']
_REGISTEREXPERIMENTTRACKINGVALUESREQUEST = DESCRIPTOR.message_types_by_name['RegisterExperimentTrackingValuesRequest']
_REGISTEREXPERIMENTTRACKINGVALUESRESPONSE = DESCRIPTOR.message_types_by_name['RegisterExperimentTrackingValuesResponse']
_EXPERIMENTTRACKINGVALUES = DESCRIPTOR.message_types_by_name['ExperimentTrackingValues']
_BUILDCONFIGURATION = DESCRIPTOR.message_types_by_name['BuildConfiguration']
_STEP = DESCRIPTOR.message_types_by_name['Step']
_BUILDPROPERTIESPROTO = DESCRIPTOR.message_types_by_name['BuildPropertiesProto']
_BUILDMODELURI = DESCRIPTOR.message_types_by_name['BuildModelUri']
_BUILDENVIRONMENT = DESCRIPTOR.message_types_by_name['BuildEnvironment']
_DOCKERBUILD = DESCRIPTOR.message_types_by_name['DockerBuild']
_DOCKERBUILD_BUILDARGSENTRY = _DOCKERBUILD.nested_types_by_name['BuildArgsEntry']
_LOCALBUILD = DESCRIPTOR.message_types_by_name['LocalBuild']
_PYTHONBUILD = DESCRIPTOR.message_types_by_name['PythonBuild']
_CONDABUILD = DESCRIPTOR.message_types_by_name['CondaBuild']
_POETRYBUILD = DESCRIPTOR.message_types_by_name['PoetryBuild']
_VIRTUALENVIRONMENTBUILD = DESCRIPTOR.message_types_by_name['VirtualEnvironmentBuild']
_REMOTEBUILD = DESCRIPTOR.message_types_by_name['RemoteBuild']
_REMOTEBUILDRESOURCES = DESCRIPTOR.message_types_by_name['RemoteBuildResources']
_METRIC = DESCRIPTOR.message_types_by_name['Metric']
_PARAM = DESCRIPTOR.message_types_by_name['Param']
_REGISTERMODELSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['RegisterModelSchemaResponse']
_REGISTERBUILDRESPONSE = DESCRIPTOR.message_types_by_name['RegisterBuildResponse']
_UPDATEBUILDSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateBuildStatusRequest']
_UPDATEBUILDSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateBuildStatusResponse']
_UPDATEBUILDBRANCHREQUEST = DESCRIPTOR.message_types_by_name['UpdateBuildBranchRequest']
_UPDATEBUILDBRANCHRESPONSE = DESCRIPTOR.message_types_by_name['UpdateBuildBranchResponse']
_GETBUILDREQUEST = DESCRIPTOR.message_types_by_name['GetBuildRequest']
_GETBUILDRESPONSE = DESCRIPTOR.message_types_by_name['GetBuildResponse']
_LISTBUILDSREQUEST = DESCRIPTOR.message_types_by_name['ListBuildsRequest']
_LISTBUILDSRESPONSE = DESCRIPTOR.message_types_by_name['ListBuildsResponse']
_VALUETYPE_TYPES = _VALUETYPE.enum_types_by_name['Types']
_PARAMETERCATEGORY_CATEGORY = _PARAMETERCATEGORY.enum_types_by_name['Category']
Build = _reflection.GeneratedProtocolMessageType('Build', (_message.Message,), {
  'DESCRIPTOR' : _BUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Build)
  })
_sym_db.RegisterMessage(Build)

BuildSpec = _reflection.GeneratedProtocolMessageType('BuildSpec', (_message.Message,), {
  'DESCRIPTOR' : _BUILDSPEC,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BuildSpec)
  })
_sym_db.RegisterMessage(BuildSpec)

ModelSchema = _reflection.GeneratedProtocolMessageType('ModelSchema', (_message.Message,), {
  'DESCRIPTOR' : _MODELSCHEMA,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ModelSchema)
  })
_sym_db.RegisterMessage(ModelSchema)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Entity)
  })
_sym_db.RegisterMessage(Entity)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Feature)
  })
_sym_db.RegisterMessage(Feature)

OnTheFlyFeature = _reflection.GeneratedProtocolMessageType('OnTheFlyFeature', (_message.Message,), {
  'DESCRIPTOR' : _ONTHEFLYFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.OnTheFlyFeature)
  })
_sym_db.RegisterMessage(OnTheFlyFeature)

BatchFeatureV1 = _reflection.GeneratedProtocolMessageType('BatchFeatureV1', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEATUREV1,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BatchFeatureV1)
  })
_sym_db.RegisterMessage(BatchFeatureV1)

StreamingFeatureV1 = _reflection.GeneratedProtocolMessageType('StreamingFeatureV1', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGFEATUREV1,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.StreamingFeatureV1)
  })
_sym_db.RegisterMessage(StreamingFeatureV1)

BatchFeature = _reflection.GeneratedProtocolMessageType('BatchFeature', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BatchFeature)
  })
_sym_db.RegisterMessage(BatchFeature)

StreamingFeature = _reflection.GeneratedProtocolMessageType('StreamingFeature', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.StreamingFeature)
  })
_sym_db.RegisterMessage(StreamingFeature)

StreamingAggregationFeature = _reflection.GeneratedProtocolMessageType('StreamingAggregationFeature', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGAGGREGATIONFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.StreamingAggregationFeature)
  })
_sym_db.RegisterMessage(StreamingAggregationFeature)

ExplicitFeature = _reflection.GeneratedProtocolMessageType('ExplicitFeature', (_message.Message,), {
  'DESCRIPTOR' : _EXPLICITFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ExplicitFeature)
  })
_sym_db.RegisterMessage(ExplicitFeature)

RequestInput = _reflection.GeneratedProtocolMessageType('RequestInput', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINPUT,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RequestInput)
  })
_sym_db.RegisterMessage(RequestInput)

SourceFeature = _reflection.GeneratedProtocolMessageType('SourceFeature', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEFEATURE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.SourceFeature)
  })
_sym_db.RegisterMessage(SourceFeature)

Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTION,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Prediction)
  })
_sym_db.RegisterMessage(Prediction)

InferenceOutput = _reflection.GeneratedProtocolMessageType('InferenceOutput', (_message.Message,), {
  'DESCRIPTOR' : _INFERENCEOUTPUT,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.InferenceOutput)
  })
_sym_db.RegisterMessage(InferenceOutput)

ValueType = _reflection.GeneratedProtocolMessageType('ValueType', (_message.Message,), {
  'DESCRIPTOR' : _VALUETYPE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ValueType)
  })
_sym_db.RegisterMessage(ValueType)

ParameterCategory = _reflection.GeneratedProtocolMessageType('ParameterCategory', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERCATEGORY,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ParameterCategory)
  })
_sym_db.RegisterMessage(ParameterCategory)

RegisterBuildRequest = _reflection.GeneratedProtocolMessageType('RegisterBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERBUILDREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterBuildRequest)
  })
_sym_db.RegisterMessage(RegisterBuildRequest)

RegisterModelSchemaRequest = _reflection.GeneratedProtocolMessageType('RegisterModelSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMODELSCHEMAREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterModelSchemaRequest)
  })
_sym_db.RegisterMessage(RegisterModelSchemaRequest)

RegisterExperimentTrackingValuesRequest = _reflection.GeneratedProtocolMessageType('RegisterExperimentTrackingValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGVALUESREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterExperimentTrackingValuesRequest)
  })
_sym_db.RegisterMessage(RegisterExperimentTrackingValuesRequest)

RegisterExperimentTrackingValuesResponse = _reflection.GeneratedProtocolMessageType('RegisterExperimentTrackingValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXPERIMENTTRACKINGVALUESRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterExperimentTrackingValuesResponse)
  })
_sym_db.RegisterMessage(RegisterExperimentTrackingValuesResponse)

ExperimentTrackingValues = _reflection.GeneratedProtocolMessageType('ExperimentTrackingValues', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTTRACKINGVALUES,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ExperimentTrackingValues)
  })
_sym_db.RegisterMessage(ExperimentTrackingValues)

BuildConfiguration = _reflection.GeneratedProtocolMessageType('BuildConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _BUILDCONFIGURATION,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BuildConfiguration)
  })
_sym_db.RegisterMessage(BuildConfiguration)

Step = _reflection.GeneratedProtocolMessageType('Step', (_message.Message,), {
  'DESCRIPTOR' : _STEP,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Step)
  })
_sym_db.RegisterMessage(Step)

BuildPropertiesProto = _reflection.GeneratedProtocolMessageType('BuildPropertiesProto', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIESPROTO,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BuildPropertiesProto)
  })
_sym_db.RegisterMessage(BuildPropertiesProto)

BuildModelUri = _reflection.GeneratedProtocolMessageType('BuildModelUri', (_message.Message,), {
  'DESCRIPTOR' : _BUILDMODELURI,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BuildModelUri)
  })
_sym_db.RegisterMessage(BuildModelUri)

BuildEnvironment = _reflection.GeneratedProtocolMessageType('BuildEnvironment', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENVIRONMENT,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.BuildEnvironment)
  })
_sym_db.RegisterMessage(BuildEnvironment)

DockerBuild = _reflection.GeneratedProtocolMessageType('DockerBuild', (_message.Message,), {

  'BuildArgsEntry' : _reflection.GeneratedProtocolMessageType('BuildArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DOCKERBUILD_BUILDARGSENTRY,
    '__module__' : 'qwak.builds.builds_pb2'
    # @@protoc_insertion_point(class_scope:qwak.builds.management.DockerBuild.BuildArgsEntry)
    })
  ,
  'DESCRIPTOR' : _DOCKERBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.DockerBuild)
  })
_sym_db.RegisterMessage(DockerBuild)
_sym_db.RegisterMessage(DockerBuild.BuildArgsEntry)

LocalBuild = _reflection.GeneratedProtocolMessageType('LocalBuild', (_message.Message,), {
  'DESCRIPTOR' : _LOCALBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.LocalBuild)
  })
_sym_db.RegisterMessage(LocalBuild)

PythonBuild = _reflection.GeneratedProtocolMessageType('PythonBuild', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.PythonBuild)
  })
_sym_db.RegisterMessage(PythonBuild)

CondaBuild = _reflection.GeneratedProtocolMessageType('CondaBuild', (_message.Message,), {
  'DESCRIPTOR' : _CONDABUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.CondaBuild)
  })
_sym_db.RegisterMessage(CondaBuild)

PoetryBuild = _reflection.GeneratedProtocolMessageType('PoetryBuild', (_message.Message,), {
  'DESCRIPTOR' : _POETRYBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.PoetryBuild)
  })
_sym_db.RegisterMessage(PoetryBuild)

VirtualEnvironmentBuild = _reflection.GeneratedProtocolMessageType('VirtualEnvironmentBuild', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALENVIRONMENTBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.VirtualEnvironmentBuild)
  })
_sym_db.RegisterMessage(VirtualEnvironmentBuild)

RemoteBuild = _reflection.GeneratedProtocolMessageType('RemoteBuild', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILD,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RemoteBuild)
  })
_sym_db.RegisterMessage(RemoteBuild)

RemoteBuildResources = _reflection.GeneratedProtocolMessageType('RemoteBuildResources', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILDRESOURCES,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RemoteBuildResources)
  })
_sym_db.RegisterMessage(RemoteBuildResources)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Metric)
  })
_sym_db.RegisterMessage(Metric)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.Param)
  })
_sym_db.RegisterMessage(Param)

RegisterModelSchemaResponse = _reflection.GeneratedProtocolMessageType('RegisterModelSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERMODELSCHEMARESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterModelSchemaResponse)
  })
_sym_db.RegisterMessage(RegisterModelSchemaResponse)

RegisterBuildResponse = _reflection.GeneratedProtocolMessageType('RegisterBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERBUILDRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.RegisterBuildResponse)
  })
_sym_db.RegisterMessage(RegisterBuildResponse)

UpdateBuildStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateBuildStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDSTATUSREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.UpdateBuildStatusRequest)
  })
_sym_db.RegisterMessage(UpdateBuildStatusRequest)

UpdateBuildStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateBuildStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDSTATUSRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.UpdateBuildStatusResponse)
  })
_sym_db.RegisterMessage(UpdateBuildStatusResponse)

UpdateBuildBranchRequest = _reflection.GeneratedProtocolMessageType('UpdateBuildBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDBRANCHREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.UpdateBuildBranchRequest)
  })
_sym_db.RegisterMessage(UpdateBuildBranchRequest)

UpdateBuildBranchResponse = _reflection.GeneratedProtocolMessageType('UpdateBuildBranchResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUILDBRANCHRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.UpdateBuildBranchResponse)
  })
_sym_db.RegisterMessage(UpdateBuildBranchResponse)

GetBuildRequest = _reflection.GeneratedProtocolMessageType('GetBuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.GetBuildRequest)
  })
_sym_db.RegisterMessage(GetBuildRequest)

GetBuildResponse = _reflection.GeneratedProtocolMessageType('GetBuildResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBUILDRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.GetBuildResponse)
  })
_sym_db.RegisterMessage(GetBuildResponse)

ListBuildsRequest = _reflection.GeneratedProtocolMessageType('ListBuildsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDSREQUEST,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ListBuildsRequest)
  })
_sym_db.RegisterMessage(ListBuildsRequest)

ListBuildsResponse = _reflection.GeneratedProtocolMessageType('ListBuildsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUILDSRESPONSE,
  '__module__' : 'qwak.builds.builds_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.management.ListBuildsResponse)
  })
_sym_db.RegisterMessage(ListBuildsResponse)

_BUILDSMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['BuildsManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.builds.apiP\001'
  _BUILD.fields_by_name['deployment_build_status']._options = None
  _BUILD.fields_by_name['deployment_build_status']._serialized_options = b'\030\001'
  _REGISTERBUILDREQUEST.fields_by_name['model_schema']._options = None
  _REGISTERBUILDREQUEST.fields_by_name['model_schema']._serialized_options = b'\030\001'
  _REGISTERBUILDREQUEST.fields_by_name['qwak_calling_user_id']._options = None
  _REGISTERBUILDREQUEST.fields_by_name['qwak_calling_user_id']._serialized_options = b'\030\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _UPDATEBUILDSTATUSREQUEST.fields_by_name['qwak_calling_user_id']._options = None
  _UPDATEBUILDSTATUSREQUEST.fields_by_name['qwak_calling_user_id']._serialized_options = b'\030\001'
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BUILDSTATUS._serialized_start=6916
  _BUILDSTATUS._serialized_end=7148
  _BUILD._serialized_start=180
  _BUILD._serialized_end=936
  _BUILDSPEC._serialized_start=939
  _BUILDSPEC._serialized_end=1329
  _MODELSCHEMA._serialized_start=1332
  _MODELSCHEMA._serialized_end=1570
  _ENTITY._serialized_start=1572
  _ENTITY._serialized_end=1643
  _FEATURE._serialized_start=1646
  _FEATURE._serialized_end=2238
  _ONTHEFLYFEATURE._serialized_start=2241
  _ONTHEFLYFEATURE._serialized_end=2384
  _BATCHFEATUREV1._serialized_start=2386
  _BATCHFEATUREV1._serialized_end=2464
  _STREAMINGFEATUREV1._serialized_start=2466
  _STREAMINGFEATUREV1._serialized_end=2548
  _BATCHFEATURE._serialized_start=2550
  _BATCHFEATURE._serialized_end=2626
  _STREAMINGFEATURE._serialized_start=2628
  _STREAMINGFEATURE._serialized_end=2708
  _STREAMINGAGGREGATIONFEATURE._serialized_start=2710
  _STREAMINGAGGREGATIONFEATURE._serialized_end=2801
  _EXPLICITFEATURE._serialized_start=2803
  _EXPLICITFEATURE._serialized_end=2883
  _REQUESTINPUT._serialized_start=2885
  _REQUESTINPUT._serialized_end=2962
  _SOURCEFEATURE._serialized_start=2965
  _SOURCEFEATURE._serialized_end=3120
  _PREDICTION._serialized_start=3122
  _PREDICTION._serialized_end=3197
  _INFERENCEOUTPUT._serialized_start=3199
  _INFERENCEOUTPUT._serialized_end=3279
  _VALUETYPE._serialized_start=3282
  _VALUETYPE._serialized_end=3448
  _VALUETYPE_TYPES._serialized_start=3350
  _VALUETYPE_TYPES._serialized_end=3448
  _PARAMETERCATEGORY._serialized_start=3450
  _PARAMETERCATEGORY._serialized_end=3556
  _PARAMETERCATEGORY_CATEGORY._serialized_start=3471
  _PARAMETERCATEGORY_CATEGORY._serialized_end=3556
  _REGISTERBUILDREQUEST._serialized_start=3559
  _REGISTERBUILDREQUEST._serialized_end=3733
  _REGISTERMODELSCHEMAREQUEST._serialized_start=3735
  _REGISTERMODELSCHEMAREQUEST._serialized_end=3840
  _REGISTEREXPERIMENTTRACKINGVALUESREQUEST._serialized_start=3843
  _REGISTEREXPERIMENTTRACKINGVALUESREQUEST._serialized_end=3988
  _REGISTEREXPERIMENTTRACKINGVALUESRESPONSE._serialized_start=3990
  _REGISTEREXPERIMENTTRACKINGVALUESRESPONSE._serialized_end=4032
  _EXPERIMENTTRACKINGVALUES._serialized_start=4034
  _EXPERIMENTTRACKINGVALUES._serialized_end=4156
  _BUILDCONFIGURATION._serialized_start=4159
  _BUILDCONFIGURATION._serialized_end=4496
  _STEP._serialized_start=4498
  _STEP._serialized_end=4593
  _BUILDPROPERTIESPROTO._serialized_start=4596
  _BUILDPROPERTIESPROTO._serialized_end=4792
  _BUILDMODELURI._serialized_start=4794
  _BUILDMODELURI._serialized_end=4897
  _BUILDENVIRONMENT._serialized_start=4900
  _BUILDENVIRONMENT._serialized_end=5132
  _DOCKERBUILD._serialized_start=5135
  _DOCKERBUILD._serialized_end=5401
  _DOCKERBUILD_BUILDARGSENTRY._serialized_start=5353
  _DOCKERBUILD_BUILDARGSENTRY._serialized_end=5401
  _LOCALBUILD._serialized_start=5403
  _LOCALBUILD._serialized_end=5453
  _PYTHONBUILD._serialized_start=5456
  _PYTHONBUILD._serialized_end=5739
  _CONDABUILD._serialized_start=5741
  _CONDABUILD._serialized_end=5773
  _POETRYBUILD._serialized_start=5775
  _POETRYBUILD._serialized_end=5831
  _VIRTUALENVIRONMENTBUILD._serialized_start=5833
  _VIRTUALENVIRONMENTBUILD._serialized_end=5908
  _REMOTEBUILD._serialized_start=5910
  _REMOTEBUILD._serialized_end=6007
  _REMOTEBUILDRESOURCES._serialized_start=6010
  _REMOTEBUILDRESOURCES._serialized_end=6153
  _METRIC._serialized_start=6155
  _METRIC._serialized_end=6191
  _PARAM._serialized_start=6193
  _PARAM._serialized_end=6228
  _REGISTERMODELSCHEMARESPONSE._serialized_start=6230
  _REGISTERMODELSCHEMARESPONSE._serialized_end=6259
  _REGISTERBUILDRESPONSE._serialized_start=6261
  _REGISTERBUILDRESPONSE._serialized_end=6361
  _UPDATEBUILDSTATUSREQUEST._serialized_start=6364
  _UPDATEBUILDSTATUSREQUEST._serialized_end=6533
  _UPDATEBUILDSTATUSRESPONSE._serialized_start=6535
  _UPDATEBUILDSTATUSRESPONSE._serialized_end=6562
  _UPDATEBUILDBRANCHREQUEST._serialized_start=6564
  _UPDATEBUILDBRANCHREQUEST._serialized_end=6629
  _UPDATEBUILDBRANCHRESPONSE._serialized_start=6631
  _UPDATEBUILDBRANCHRESPONSE._serialized_end=6658
  _GETBUILDREQUEST._serialized_start=6660
  _GETBUILDREQUEST._serialized_end=6695
  _GETBUILDRESPONSE._serialized_start=6697
  _GETBUILDRESPONSE._serialized_end=6761
  _LISTBUILDSREQUEST._serialized_start=6763
  _LISTBUILDSREQUEST._serialized_end=6844
  _LISTBUILDSRESPONSE._serialized_start=6846
  _LISTBUILDSRESPONSE._serialized_end=6913
  _BUILDSMANAGEMENTSERVICE._serialized_start=7151
  _BUILDSMANAGEMENTSERVICE._serialized_end=7900
# @@protoc_insertion_point(module_scope)



import uuid
from typing import Optional

from _qwak_proto.qwak.features_operator.v3.features_operator_async_service_pb2 import (
    ValidationResponse,
)
from _qwak_proto.qwak.features_operator.v3.features_operator_async_service_pb2_grpc import (
    FeaturesOperatorAsyncServiceServicer,
)


class FeaturesOperatorV3ServiceMock(FeaturesOperatorAsyncServiceServicer):
    def __init__(self):
        self.response: Optional[ValidationResponse] = None
        super(FeaturesOperatorV3ServiceMock, self).__init__()

    def given_next_response(self, response: ValidationResponse):
        self.response = response

    def ValidateDataSource(self, request, context) -> str:
        request_id = str(uuid.uuid4())
        return ValidationResponse(request_id=request_id)

    def ValidateFeatureSet(self, request, context):
        request_id = str(uuid.uuid4())
        return ValidationResponse(request_id=request_id)

    def GetValidationResult(self, request, context):
        return self.response



from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Optional, Type

from _qwak_proto.qwak.build.v1.build_pb2 import (
    BatchFeatureV1 as ProtoBatchFeatureV1,
    Entity as ProtoEntity,
    ExplicitFeature as ProtoExplicitFeature,
    Feature as ProtoFeature,
    InferenceOutput as ProtoInferenceOutput,
    Prediction as ProtoPrediction,
    RequestInput as ProtoRequestInput,
    ValueType,
)


@dataclass(unsafe_hash=True)
class Entity:
    name: str
    type: Type = str

    def to_proto(self):
        return ProtoEntity(
            name=self.name, type=ValueType(type=_type_conversion(self.type))
        )


@dataclass
class BaseFeature(ABC):
    name: str

    @abstractmethod
    def to_proto(self):
        pass


@dataclass(unsafe_hash=True)
class ExplicitFeature(BaseFeature):
    type: Type

    def to_proto(self):
        return ProtoFeature(
            explicit_feature=ProtoExplicitFeature(
                name=self.name, type=ValueType(type=_type_conversion(self.type))
            )
        )


@dataclass(unsafe_hash=True)
class RequestInput(BaseFeature):
    type: Type

    def to_proto(self):
        return ProtoFeature(
            request_input=ProtoRequestInput(
                name=self.name, type=ValueType(type=_type_conversion(self.type))
            )
        )


@dataclass(unsafe_hash=True)
class FeatureStoreInput(BaseFeature):
    entity: Optional[Entity] = None

    def to_proto(self):
        return ProtoFeature(
            batch_feature_v1=ProtoBatchFeatureV1(
                name=self.name, entity=self.entity.to_proto() if self.entity else None
            )
        )


@dataclass(unsafe_hash=True)
class InferenceOutput:
    name: str
    type: type

    def to_proto(self):
        return ProtoInferenceOutput(
            name=self.name, type=ValueType(type=_type_conversion(self.type))
        )


@dataclass(unsafe_hash=True)
class Prediction:
    name: str
    type: type

    def to_proto(self):
        return ProtoPrediction(
            name=self.name, type=ValueType(type=_type_conversion(self.type))
        )


def _type_conversion(type):
    if type == int:
        return ValueType.INT32
    elif type == str:
        return ValueType.STRING
    elif type == bytes:
        return ValueType.BYTES
    elif type == bool:
        return ValueType.BOOL
    elif type == float:
        return ValueType.FLOAT



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AlertType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AlertTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AlertType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALERT_TYPE_NOT_VALID: _AlertType.ValueType  # 0
    ERROR_RATE: _AlertType.ValueType  # 1
    THROUGHPUT: _AlertType.ValueType  # 2
    LATENCY: _AlertType.ValueType  # 3
    LATENCY_90: _AlertType.ValueType  # 4
    LATENCY_95: _AlertType.ValueType  # 5

class AlertType(_AlertType, metaclass=_AlertTypeEnumTypeWrapper): ...

ALERT_TYPE_NOT_VALID: AlertType.ValueType  # 0
ERROR_RATE: AlertType.ValueType  # 1
THROUGHPUT: AlertType.ValueType  # 2
LATENCY: AlertType.ValueType  # 3
LATENCY_90: AlertType.ValueType  # 4
LATENCY_95: AlertType.ValueType  # 5
global___AlertType = AlertType

class _ReducerFunction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReducerFunctionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReducerFunction.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REDUCER_FUNCTION_NOT_VALID: _ReducerFunction.ValueType  # 0
    MIN: _ReducerFunction.ValueType  # 1
    MAX: _ReducerFunction.ValueType  # 2
    SUM: _ReducerFunction.ValueType  # 3
    COUNT: _ReducerFunction.ValueType  # 4
    LAST: _ReducerFunction.ValueType  # 5
    MEDIAN: _ReducerFunction.ValueType  # 6
    DIFF: _ReducerFunction.ValueType  # 7
    DIFF_ABS: _ReducerFunction.ValueType  # 8
    PERCENT_DIFF: _ReducerFunction.ValueType  # 9
    PERCENT_DIFF_ABS: _ReducerFunction.ValueType  # 10

class ReducerFunction(_ReducerFunction, metaclass=_ReducerFunctionEnumTypeWrapper): ...

REDUCER_FUNCTION_NOT_VALID: ReducerFunction.ValueType  # 0
MIN: ReducerFunction.ValueType  # 1
MAX: ReducerFunction.ValueType  # 2
SUM: ReducerFunction.ValueType  # 3
COUNT: ReducerFunction.ValueType  # 4
LAST: ReducerFunction.ValueType  # 5
MEDIAN: ReducerFunction.ValueType  # 6
DIFF: ReducerFunction.ValueType  # 7
DIFF_ABS: ReducerFunction.ValueType  # 8
PERCENT_DIFF: ReducerFunction.ValueType  # 9
PERCENT_DIFF_ABS: ReducerFunction.ValueType  # 10
global___ReducerFunction = ReducerFunction

class _EvaluatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EvaluatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EvaluatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EVALUATOR_TYPE_NOT_VALID: _EvaluatorType.ValueType  # 0
    IS_ABOVE: _EvaluatorType.ValueType  # 1
    IS_BELOW: _EvaluatorType.ValueType  # 2

class EvaluatorType(_EvaluatorType, metaclass=_EvaluatorTypeEnumTypeWrapper): ...

EVALUATOR_TYPE_NOT_VALID: EvaluatorType.ValueType  # 0
IS_ABOVE: EvaluatorType.ValueType  # 1
IS_BELOW: EvaluatorType.ValueType  # 2
global___EvaluatorType = EvaluatorType

class AlertRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALERT_SPEC_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_CHANNELS_FIELD_NUMBER: builtins.int
    ALERT_ID_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    SELECTED_VARIATION_NAME_FIELD_NUMBER: builtins.int
    @property
    def alert_spec(self) -> global___AlertSpec:
        """The definition of the alert rule"""
    @property
    def notifications_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotificationChannelSpec]:
        """The notification channels to notify to"""
    alert_id: builtins.str
    """The alert id"""
    is_enabled: builtins.bool
    """If the alert rule is active."""
    selected_variation_name: builtins.str
    """The variation Name to apply alert on"""
    def __init__(
        self,
        *,
        alert_spec: global___AlertSpec | None = ...,
        notifications_channels: collections.abc.Iterable[global___NotificationChannelSpec] | None = ...,
        alert_id: builtins.str = ...,
        is_enabled: builtins.bool = ...,
        selected_variation_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alert_spec", b"alert_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_id", b"alert_id", "alert_spec", b"alert_spec", "is_enabled", b"is_enabled", "notifications_channels", b"notifications_channels", "selected_variation_name", b"selected_variation_name"]) -> None: ...

global___AlertRule = AlertRule

class AlertSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDUCER_FUNCTION_FIELD_NUMBER: builtins.int
    EVALUATOR_TYPE_FIELD_NUMBER: builtins.int
    EVALUATOR_THRESHOLD_FIELD_NUMBER: builtins.int
    EVALUATION_PERIOD_FIELD_NUMBER: builtins.int
    ALERT_TYPE_FIELD_NUMBER: builtins.int
    EVALUATION_THRESHOLD_FIELD_NUMBER: builtins.int
    reducer_function: global___ReducerFunction.ValueType
    """Reducer Function e.g. min, max"""
    evaluator_type: global___EvaluatorType.ValueType
    """Evaluator function type e.g. greeter then, lower then"""
    evaluator_threshold: builtins.int
    """Evaluator threshold to alert for"""
    evaluation_period: builtins.int
    """Evaluation period"""
    alert_type: global___AlertType.ValueType
    """The type of the alert"""
    evaluation_threshold: builtins.float
    """Evaluation threshold"""
    def __init__(
        self,
        *,
        reducer_function: global___ReducerFunction.ValueType = ...,
        evaluator_type: global___EvaluatorType.ValueType = ...,
        evaluator_threshold: builtins.int = ...,
        evaluation_period: builtins.int = ...,
        alert_type: global___AlertType.ValueType = ...,
        evaluation_threshold: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_type", b"alert_type", "evaluation_period", b"evaluation_period", "evaluation_threshold", b"evaluation_threshold", "evaluator_threshold", b"evaluator_threshold", "evaluator_type", b"evaluator_type", "reducer_function", b"reducer_function"]) -> None: ...

global___AlertSpec = AlertSpec

class NotificationChannelSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    NOTIFICATION_CHANNEL_NAME_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    """The Id for notification"""
    notification_channel_name: builtins.str
    """The Notification Name to display"""
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        notification_channel_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channel_id", b"notification_channel_id", "notification_channel_name", b"notification_channel_name"]) -> None: ...

global___NotificationChannelSpec = NotificationChannelSpec

class NotificationChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    NOTIFICATION_CHANNEL_NAME_FIELD_NUMBER: builtins.int
    NOTIFICATION_SETTINGS_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    """The Id for notification"""
    notification_channel_name: builtins.str
    """The Notification Name to display"""
    @property
    def notification_settings(self) -> global___NotificationChannelSettings:
        """The settings of the notification channel"""
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        notification_channel_name: builtins.str = ...,
        notification_settings: global___NotificationChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_settings", b"notification_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channel_id", b"notification_channel_id", "notification_channel_name", b"notification_channel_name", "notification_settings", b"notification_settings"]) -> None: ...

global___NotificationChannel = NotificationChannel

class NotificationChannelSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_SETTINGS_FIELD_NUMBER: builtins.int
    OPSGENIE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def slack_settings(self) -> global___SlackSettings: ...
    @property
    def opsgenie_settings(self) -> global___OpsgenieSettings: ...
    def __init__(
        self,
        *,
        slack_settings: global___SlackSettings | None = ...,
        opsgenie_settings: global___OpsgenieSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["opsgenie_settings", b"opsgenie_settings", "slack_settings", b"slack_settings", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["opsgenie_settings", b"opsgenie_settings", "slack_settings", b"slack_settings", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["slack_settings", "opsgenie_settings"] | None: ...

global___NotificationChannelSettings = NotificationChannelSettings

class SlackSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """Url of webhook of slack channel"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___SlackSettings = SlackSettings

class OpsgenieSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_URL_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    api_url: builtins.str
    """The API URL for Opsgenie instance"""
    api_key: builtins.str
    """The API Key as provided by Opsgenie for configured Grafana integration."""
    def __init__(
        self,
        *,
        api_url: builtins.str = ...,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "api_url", b"api_url"]) -> None: ...

global___OpsgenieSettings = OpsgenieSettings
